# Changelog

## [0.2.0](https://github.com/SoferAi/torah-dl/compare/v0.1.0...v0.2.0) (2024-12-04)


### Features

* add yutorah and cli functionality ([#2](https://github.com/SoferAi/torah-dl/issues/2)) ([09320c0](https://github.com/SoferAi/torah-dl/commit/09320c0af7e358f14e3ee9e086efa93a885d6632))
* **docs:** mike and mkdocs ([#4](https://github.com/SoferAi/torah-dl/issues/4)) ([a4b13ef](https://github.com/SoferAi/torah-dl/commit/a4b13efffe124507df10d22f72d5174590827ca9))

## 0.1.0 (2024-11-29)


### Features

* **docs:** update docs ([c0ebdf9](https://github.com/SoferAi/torah-dl/commit/c0ebdf9ad6528b2437f4b38ea24dfbf4fc49c684))
